pub struct IdlMissingTypes {
pub global_admin: Pubkey,
pub global_config: Pubkey,
}Expand description
Generated client accounts for IdlMissingTypes.
Fields
global_admin: Pubkeyglobal_config: PubkeyTrait Implementations
Sourceimpl BorshSerialize for IdlMissingTypeswhere
Pubkey: BorshSerialize,
impl BorshSerialize for IdlMissingTypeswhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for IdlMissingTypes
impl ToAccountMetas for IdlMissingTypes
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for IdlMissingTypes
impl RefUnwindSafe for IdlMissingTypes
impl Send for IdlMissingTypes
impl Sync for IdlMissingTypes
impl Unpin for IdlMissingTypes
impl UnsafeUnpin for IdlMissingTypes
impl UnwindSafe for IdlMissingTypes