pub struct UpdateGlobalConfig {
pub global_admin: Pubkey,
pub global_config: Pubkey,
}Expand description
Generated client accounts for UpdateGlobalConfig.
Fields
global_admin: Pubkeyglobal_config: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateGlobalConfigwhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateGlobalConfigwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateGlobalConfig
impl ToAccountMetas for UpdateGlobalConfig
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateGlobalConfig
impl RefUnwindSafe for UpdateGlobalConfig
impl Send for UpdateGlobalConfig
impl Sync for UpdateGlobalConfig
impl Unpin for UpdateGlobalConfig
impl UnsafeUnpin for UpdateGlobalConfig
impl UnwindSafe for UpdateGlobalConfig