#[repr(C)]pub struct DatedPrice {
pub price: Price,
pub last_updated_slot: u64,
pub unix_timestamp: u64,
pub reserved: [u64; 2],
pub reserved2: [u16; 3],
pub index: u16,
}Fields
price: Pricelast_updated_slot: u64unix_timestamp: u64reserved: [u64; 2]reserved2: [u16; 3]index: u16Trait Implementations
Sourceimpl BorshDeserialize for DatedPricewhere
Price: BorshDeserialize,
u64: BorshDeserialize,
[u64; 2]: BorshDeserialize,
[u16; 3]: BorshDeserialize,
u16: BorshDeserialize,
impl BorshDeserialize for DatedPricewhere
Price: BorshDeserialize,
u64: BorshDeserialize,
[u64; 2]: BorshDeserialize,
[u16; 3]: BorshDeserialize,
u16: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DatedPricewhere
Price: BorshSerialize,
u64: BorshSerialize,
[u64; 2]: BorshSerialize,
[u16; 3]: BorshSerialize,
u16: BorshSerialize,
impl BorshSerialize for DatedPricewhere
Price: BorshSerialize,
u64: BorshSerialize,
[u64; 2]: BorshSerialize,
[u16; 3]: BorshSerialize,
u16: BorshSerialize,
Sourceimpl Clone for DatedPrice
impl Clone for DatedPrice
Sourcefn clone(&self) -> DatedPrice
fn clone(&self) -> DatedPrice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DatedPrice
Sourceimpl Debug for DatedPrice
impl Debug for DatedPrice
Sourceimpl Default for DatedPrice
impl Default for DatedPrice
Sourcefn default() -> DatedPrice
fn default() -> DatedPrice
Returns the “default value” for a type. Read more