#[repr(C)]pub struct Price {
pub value: u64,
pub exp: u64,
}Fields
value: u64exp: u64Trait Implementations
Sourceimpl BorshDeserialize for Pricewhere
u64: BorshDeserialize,
impl BorshDeserialize for Pricewhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Pricewhere
u64: BorshSerialize,
impl BorshSerialize for Pricewhere
u64: BorshSerialize,
impl Copy for Price